import requests

class Cleverbot():
	def __init__(self, user, api_key, nick="Bot"):
		self.session = requests.Session()
		self.user = user
		self.key = api_key
		self.nick = nick


	def create_session(self):
		params = {
			"user": self.user,
			"key": self.key,
			"nick": self.nick
		}
		resp = self.session.post("https://cleverbot.io/1.0/create", data=params)
	
	def say(self, text):
		params = {
			"user": self.user,
			"key": self.key,
			"nick": self.nick,
			"text": text
		}

		resp = self.session.post("https://cleverbot.io/1.0/ask", data=params)
		data = resp.json()
		return data


from cleverbot import Cleverbot
import asyncio

cb = Cleverbot("ud577fnPv6KuTKJ8", "XN0Q5y6wpHn83S9NZXuNf3PJnTc75qXD", "testing")



async def test():
	await cb.create_session()
	c = await cb.say("test")
	print(c["response"])

event = asyncio.get_event_loop()
event.run_until_complete(test())


import aiohttp
import asyncio

class Cleverbot():
	def __init__(self, user, api_key, nick="Bot"):
		self.session = aiohttp.ClientSession()
		self.user = user
		self.key = api_key
		self.nick = nick

	def __del__(self):
		if not self.session.closed:
			if self.session._connector_owner:
				self.session._connector.close()
				self.session._connector = None

	async def create_session(self):
		params = {
			"user": self.user,
			"key": self.key,
			"nick": self.nick
		}
		async with self.session.post("https://cleverbot.io/1.0/create", data=params) as resp:
			data = await resp.json()
	
	async def say(self, text):
		params = {
			"user": self.user,
			"key": self.key,
			"nick": self.nick,
			"text": text
		}
		async with self.session.post("https://cleverbot.io/1.0/ask", data=params) as resp:
			data = await resp.json()
		return data


from setuptools import setup

with open('README.rst') as f:
    readme = f.read()

setup(name='cleverbotio',
    version="1.0",
    description="A Python wrapper for the Cleverbot.io API that has an async option",
    long_description=readme,
    url='https://github.com/shadeyg56/cleverbotio.py',
    author='shadeyg56',
    license="GNU",
    packages=['Cleverbotio', 'Cleverbotio.async'],
    install_requires=['requests>=1.0.0'],
    extras_require={'async': ['aiohttp>=1.0.0']},
    keywords = ["cleverbot", "async", "api-wrapper"]
)